==> segatex-7.900.tar.gz: segatex-7.900/admin/sqlrefpolicy_prepare2.sh <==
#
# segatex SELinux tool.
#
# Copyright (C) 2007-2010 Shintaro Fujiwara 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#!/bin/sh
######this script basically echoes every lines in current directory recursively.
OUTPUTFILE_PRE="interface_allow.txt_pre_test"
OUTPUTFILE_PRE2="interface_allow.txt_pre2_test"
OUTPUTFILE_PRE3="interface_allow.txt_pre3_test"
OUTPUTFILE="interface_allow.txt"

ECHO_LINES(){
	for filename in $(find $1 | sort ); do
		if [ -d $filename ]; then
			continue
		else
			TEMP_STR=`echo $filename | grep ".if_raw$"`
			if [ "$TEMP_STR" != "" ]; then
				echo "filename:"$filename
				while read LINE
				do
					INTERFACE_NAME=`echo $LINE | grep "'$"`
					if [ "$INTERFACE_NAME" != "" ]; then
						echo "$filename"",""$INTERFACE_NAME"
					fi
					echo $LINE | grep "^allow"
				done < $filename >> $OUTPUTFILE_PRE
			fi
		fi
	done
}
unlink $OUTPUTFILE_PRE
unlink $OUTPUTFILE_PRE2
unlink $OUTPUTFILE_PRE3
unlink $OUTPUTFILE
ECHO_LINES
sed 's/\//,/g' $OUTPUTFILE_PRE > $OUTPUTFILE_PRE2
sed 's/_raw//g' $OUTPUTFILE_PRE2 > $OUTPUTFILE_PRE3
sed 's/^.,//g' $OUTPUTFILE_PRE3 > $OUTPUTFILE

unlink $OUTPUTFILE_PRE
unlink $OUTPUTFILE_PRE2
unlink $OUTPUTFILE_PRE3

exit 0

==> segatex-7.980.tar.gz: segatex-7.980/admin/sqlrefpolicy_prepare2.sh <==
#
# segatex SELinux tool.
#
# Copyright (C) 2007-2013 Shintaro Fujiwara 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#!/bin/sh
######this script basically echoes every lines in current directory recursively.
OUTPUTFILE_PRE="interface_allow.txt_pre_test"
OUTPUTFILE_PRE2="interface_allow.txt_pre2_test"
OUTPUTFILE_PRE3="interface_allow.txt_pre3_test"
OUTPUTFILE="interface_allow.txt"

ECHO_LINES(){
	for filename in $(find $1 | sort ); do
		if [ -d $filename ]; then
			continue
		else
			TEMP_STR=`echo $filename | grep ".if_raw$"`
			if [ "$TEMP_STR" != "" ]; then
				echo "filename:"$filename
				while read LINE
				do
					#INTERFACE_NAME=`echo $LINE | grep "'$"`
					INTERFACE_NAME=`echo $LINE | grep "::"`
					if [ "$INTERFACE_NAME" != "" ]; then
						echo "$filename"",""$INTERFACE_NAME"
					fi
					echo $LINE | grep "^allow"
				done < $filename >> $OUTPUTFILE_PRE
			fi
		fi
	done
}
if [ -r $OUTPUTFILE_PRE ]; then
	unlink $OUTPUTFILE_PRE
fi
if [ -r $OUTPUTFILE_PRE2 ]; then
	unlink $OUTPUTFILE_PRE2
fi
if [ -r $OUTPUTFILE_PRE3 ]; then
	unlink $OUTPUTFILE_PRE3
fi
if [ -r $OUTPUTFILE ]; then
	unlink $OUTPUTFILE
fi
ECHO_LINES
sed 's/\//,/g' $OUTPUTFILE_PRE > $OUTPUTFILE_PRE2
sed 's/_raw//g' $OUTPUTFILE_PRE2 > $OUTPUTFILE_PRE3
sed 's/^.,//g' $OUTPUTFILE_PRE3 > $OUTPUTFILE

unlink $OUTPUTFILE_PRE
unlink $OUTPUTFILE_PRE2
unlink $OUTPUTFILE_PRE3
echo $OUTPUTFILE" was made !"

exit 0
